@@ -25,6 +25,7 @@
 #include "mobileconnectionwizard.h"
 #include "uiutils.h"
 #include "vpnuiplugin.h"
+#include "settings/wireguardinterfacewidget.h"
 
 // KDE
 #include <KMessageBox>
@@ -39,12 +40,14 @@
 #include <NetworkManagerQt/ConnectionSettings>
 #include <NetworkManagerQt/GsmSetting>
 #include <NetworkManagerQt/Ipv4Setting>
+#include <NetworkManagerQt/Ipv6Setting>
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/WiredSetting>
 #include <NetworkManagerQt/WirelessSetting>
 #include <NetworkManagerQt/WirelessDevice>
+#include <NetworkManagerQt/WireguardSetting>
 
 // Qt
 #include <QFileDialog>
@@ -100,17 +103,33 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
 
     setButtons(Button::Apply);
 
-    // Pre-select currently active primary connection and if there is none then just select
-    // the very first connection
-    NetworkManager::ActiveConnection::Ptr activeConnection = NetworkManager::primaryConnection();
-    if (activeConnection && activeConnection->isValid()) {
-        // Also check if the connection type is supported by KCM
-        const NetworkManager::ConnectionSettings::ConnectionType type = activeConnection->type();
-        if (UiUtils::isConnectionTypeSupported(type)) {
-            QMetaObject::invokeMethod(rootItem, "selectConnection", Q_ARG(QVariant, activeConnection->id()), Q_ARG(QVariant, activeConnection->connection()->path()));
+    NetworkManager::Connection::Ptr selectedConnection;
+
+    // Look in the arguments for a connection ID to preselect
+    static const QLatin1Literal uuidArgumentMarker { "Uuid=" };
+    for (QVariant arg : args) {
+        if (arg.canConvert(QMetaType::QString)) {
+            QString uuid = arg.toString();
+            if (uuid.startsWith(uuidArgumentMarker)) {
+                uuid = uuid.replace(uuidArgumentMarker, QString());
+                selectedConnection = NetworkManager::findConnectionByUuid(uuid);
+                qDebug() << "Selecting user connection:" << uuid;
+                break;
+            }
         }
-    } else {
-        // Select first connection
+    }
+
+    // Pre-select the currently active primary connection
+    if (!selectedConnection || !selectedConnection->isValid()) {
+        NetworkManager::ActiveConnection::Ptr activeConnection = NetworkManager::primaryConnection();
+        if (activeConnection && activeConnection->isValid()) {
+            selectedConnection = activeConnection->connection();
+            qDebug() << "Selecting active connection:" << selectedConnection->uuid();
+        }
+    }
+
+    // Select the very first connection as a fallback
+    if (!selectedConnection || !selectedConnection->isValid()) {
         NetworkManager::Connection::List connectionList = NetworkManager::listConnections();
         std::sort(connectionList.begin(), connectionList.end(), [] (const NetworkManager::Connection::Ptr &left, const NetworkManager::Connection::Ptr &right)
         {
@@ -141,15 +160,25 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
             }
         });
 
-        Q_FOREACH (const NetworkManager::Connection::Ptr &connection, connectionList) {
+        for (const NetworkManager::Connection::Ptr &connection : connectionList) {
             const NetworkManager::ConnectionSettings::ConnectionType type = connection->settings()->connectionType();
             if (UiUtils::isConnectionTypeSupported(type)) {
-                QMetaObject::invokeMethod(rootItem, "selectConnection", Q_ARG(QVariant, connection->settings()->id()), Q_ARG(QVariant, connection->path()));
+                selectedConnection = connection;
+                qDebug() << "Selecting first connection:" << connection->uuid();
                 break;
             }
         }
     }
 
+    if (selectedConnection && selectedConnection->isValid()) {
+        const NetworkManager::ConnectionSettings::Ptr settings = selectedConnection->settings();
+        if (UiUtils::isConnectionTypeSupported(settings->connectionType())) {
+            QMetaObject::invokeMethod(rootItem, "selectConnection", Q_ARG(QVariant, settings->id()), Q_ARG(QVariant, selectedConnection->path()));
+        }
+    } else {
+        qDebug() << "Cannot preselect a connection";
+    }
+
     connect(NetworkManager::settingsNotifier(), &NetworkManager::SettingsNotifier::connectionAdded, this, &KCMNetworkmanagement::onConnectionAdded, Qt::UniqueConnection);
 
     // Initialize first scan and then scan every 15 seconds
@@ -159,7 +188,6 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
     m_timer->setInterval(15000);
     connect(m_timer, &QTimer::timeout, [this] () {
         m_handler->requestScan();
-        m_timer->start();
     });
     m_timer->start();
 }
@@ -306,7 +334,7 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
                     wifiSetting->setMode(NetworkManager::WirelessSetting::Adhoc);
                     wifiSetting->setSsid(i18n("my_shared_connection").toUtf8());
 
-                    Q_FOREACH (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
+                    for (const NetworkManager::Device::Ptr & device : NetworkManager::networkInterfaces()) {
                         if (device->type() == NetworkManager::Device::Wifi) {
                             NetworkManager::WirelessDevice::Ptr wifiDev = device.objectCast<NetworkManager::WirelessDevice>();
                             if (wifiDev) {
@@ -324,6 +352,14 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
                 connectionSettings->setAutoconnect(false);
             }
         }
+        if (type == NetworkManager::ConnectionSettings::WireGuard) {
+            NetworkManager::WireGuardSetting::Ptr wireguardSetting = connectionSettings->setting(NetworkManager::Setting::WireGuard).dynamicCast<NetworkManager::WireGuardSetting>();
+            NetworkManager::Ipv4Setting::Ptr ipv4Setting = connectionSettings->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
+            NetworkManager::Ipv6Setting::Ptr ipv6Setting = connectionSettings->setting(NetworkManager::Setting::Ipv6).dynamicCast<NetworkManager::Ipv6Setting>();
+            connectionSettings->setAutoconnect(false);
+            ipv4Setting->setMethod(NetworkManager::Ipv4Setting::Disabled);
+            ipv6Setting->setMethod(NetworkManager::Ipv6Setting::Ignored);
+        }
         // Generate new UUID
         connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
         addConnection(connectionSettings);
@@ -459,7 +495,7 @@ void KCMNetworkmanagement::importVpn()
     // get the list of supported extensions
     const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
     QString extensions;
-    Q_FOREACH (const KService::Ptr &service, services) {
+    for (const KService::Ptr &service : services) {
         VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
         if (vpnPlugin) {
             extensions += vpnPlugin->supportedFileExtensions() % QStringLiteral(" ");
@@ -476,7 +512,23 @@ void KCMNetworkmanagement::importVpn()
         const QString ext = QStringLiteral("*.") % fi.suffix();
         qCDebug(PLASMA_NM) << "Importing VPN connection " << filename << "extension:" << ext;
 
-        Q_FOREACH (const KService::Ptr &service, services) {
+        // Handle WireGuard separately because it is different than all the other VPNs
+        if (WireGuardInterfaceWidget::supportedFileExtensions().contains(ext)) {
+            NMVariantMapMap connection = WireGuardInterfaceWidget::importConnectionSettings(filename);
+            NetworkManager::ConnectionSettings connectionSettings;
+            connectionSettings.fromMap(connection);
+            connectionSettings.setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+
+            // qCDebug(PLASMA_NM) << "Converted connection:" << connectionSettings;
+
+            m_handler->addConnection(connectionSettings.toMap());
+            // qCDebug(PLASMA_NM) << "Adding imported connection under id:" << conId;
+
+            if (!connection.isEmpty()) {
+                return; // get out if the import produced at least some output
+            }
+        }
+        for (const KService::Ptr &service : services) {
             VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
             if (vpnPlugin && vpnPlugin->supportedFileExtensions().contains(ext)) {
                 qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
